#!/usr/bin/env python
#-*- coding: utf-8 -*-

from __future__ import absolute_import
from __future__ import print_function
import argparse
import logging
import socket
import sys
import os
import six.moves.configparser
from everything.manager import Manager


def main():
    socket.setdefaulttimeout(30)
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    default_logfile = os.path.join(os.path.expanduser("~"), "everything.log")
    parser.add_argument(
        "-l", "--logfile", default=default_logfile, help="Write log to FILE")
    parser.add_argument("-c", "--config", help="Read config from FILE", required=True)
    parser.add_argument("--debug", action="store_true")
    parser.add_argument("--newconfig", action="store_true")
    args = parser.parse_args()
    mgr = Manager(verbosity=logging.DEBUG if args.debug else logging.INFO,
                  conffile=args.config,
                  logfile=args.logfile)
    if args.newconfig:
        if os.path.exists(args.config):
            print(("Configuration file {} already exists NOT overwriting".format(
                args.config)))
            sys.exit(1)
        else:
            config = six.moves.configparser.RawConfigParser(mgr.default_config)
            mgr.writeconf(config)
            sys.exit(0)
    if not mgr.configure():
        print("everything configuration failed")
        sys.exit(1)
    mgr.show(log=True, buff=None)
    mgr.run()


def newconfig():
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument("configfile", help="config file to write to")
    args = parser.parse_args()
    if os.path.exists(args.configfile):
        print(("Configuration file {} already exists NOT overwriting".format(
            args.configfile)))
        sys.exit(1)
    mgr = Manager(verbosity=logging.INFO, conffile=args.configfile)
    config = six.moves.configparser.RawConfigParser(mgr.default_config)
    mgr.writeconf(config)



if __name__ == "__main__":
    main()
