# -*- coding: utf8 -*-

"""
Insère un fichier joint à partir d'un résulat accueil de type FIC
"""

from __future__ import absolute_import
import os

from everything.workers.base import Worker
import everything.constants as constants


class WorkerAccueil(Worker):
    need_bdd = True

    def process(self, filename):
        cursor = self.conn.cursor()
        cursor.execute("""
        SELECT r.id, r.demande, t.id, da.automate, da.id
        FROM resultat r
        JOIN testbio t ON t.id = r.testbio
        JOIN demande d ON d.id = r.demande
        JOIN dem_auto da ON da.demande = d.id
        JOIN dem_auto_test dat ON (
            dat.dem_auto = da.id AND dat.testbio = t.id
        )
        JOIN type_resu tr ON tr.typ = t.type_resu
        LEFT JOIN graphique g ON g.resultat_id = r.id
        WHERE
            tr.code = 'FIC'
            AND r.actif
            AND g.id IS NULL
            AND r.resu = %s
            AND d.date_demande > now()::date - '%s days'::interval
        """, [
            filename,
            self.config["age_max_demande"],
        ])
        rows = cursor.fetchall()
        self.conn.commit()
        if len(rows) > 1:
            self.logger.error(
                u"%s - Il y a plusieurs résultats correspondants: %s",
                filename, ",".join([r[0] for r in rows]))
            return constants.MOVE_TO_ERROR
        elif len(rows) == 1:
            id_resultat, demande, testbio, automate, dem_auto = rows[0]
            with open(os.path.join(self.config["dirfich"], filename)) as f:
                bufimg = f.read()
            if filename.lower().endswith("pdf"):
                imgformat = "PDF"
            else:
                imgformat = "png"
            self.save_img(
                filename, demande, dem_auto, testbio, bufimg,
                imgformat, automate, id_resultat)
            return constants.MOVE_TO_DONE
        else:
            self.logger.info(u"Aucun résultat ne correspond au fichier %s", filename)
            return constants.DONT_MOVE

    def list_files(self):
        files = []
        for filename in os.listdir(self.config["dirfich"]):
            path = os.path.join(self.config["dirfich"], filename)
            if (
                os.path.isfile(path)
                and self.config["fname_re"].match(filename)
            ):
                files.append(filename)
        return files
