# -*- coding: utf-8 -*-

from __future__ import absolute_import
import os

from everything.workers.tuple import WorkerTuple
from everything.constants import MOVE_TO_ERROR


class WorkerAutovue(WorkerTuple):
    """
    Lis en BDD une liste de fichier à récupérer
    Récupère les fichiers sur le FTP et les ramène dans le dossier
    local
    """
    need_samba = True
    need_bdd = True
    subfolders = ['erreur', 'traite']
    sql = """
select distinct r.resu, da.demande, da.id, tb.id, r.id
from resultat as r
join testbio as tb on (tb.id = r.testbio)
join dem_auto as da on (da.demande = r.demande)
join demande as d on (da.demande=d.id)
left outer join graphique as g on (g.dem_auto = da.id and g.testbio = r.testbio and g.seq = r.seq)
where g.graphe is null
and tb.code = %(code_test)s
and da.automate = %(paillasse)s
and d.date_demande > now() - '%(age_max_demande)s days'::interval
and r.date_resu > now() - '%(minutes)s minutes'::interval
"""

    def list_objects(self):
        result = []
        params = {
            'code_test': self.config['code_test'],
            'paillasse': self.config.get('paillasse', 'AUTOVUE'),
            'age_max_demande': self.config['age_max_demande'],
            'minutes': self.config['minutes'],
        }
        self.logger.debug("REQUETE : %s %s", self.sql, params)
        cursor = self.conn.cursor()
        cursor.execute(self.sql, params)
        trames_m = cursor.fetchall()
        for trame, demande, dem_auto, testbio, id_resultat in trames_m:
            data = trame.split('^')[5:0:-4]
            data.extend((trame, demande, dem_auto, testbio, id_resultat))
            result.append(data)
        return result

    def process(self, data):
        filename, index_puit, trame_complete, demande, dem_auto, testbio, id_resultat = data
        index_puit = int(index_puit) - 1
        self.logger.info(
            u"%s - Numéro de puit : %s (trame complète : %s, demande : %s, dem_auto : %s, testbio : %s)",
            filename, index_puit, trame_complete, demande, dem_auto, testbio
        )
        local_filename = os.path.join(self.config['dirfich'], filename)
        if not os.path.exists(local_filename):
            self.logger.info(u"le fichier local %s est absent", local_filename)
            try:
                local_filename = self.smbget(filename)
            except:
                self.logger.info(u"le fichier %s est absent sur l automate", local_filename)
                return
        if not local_filename:
            # Erreur FTP, le message de log sera émit par le FTP
            return
        local_filename = os.path.basename(local_filename)
        result_split = self.split_image(local_filename, return_filenames_on_success=True)
        if result_split == MOVE_TO_ERROR:
            # Erreur de split
            self.logger.debug(u"Probleme de decoupage de l image : %s ",result_split)
            return

        wanted_filename = "%d_%s.JPEG" % (index_puit, filename)
        for splitted_filename in result_split:
            if os.path.basename(splitted_filename) == wanted_filename:
                self.logger.debug("Cropped filename : %s", splitted_filename)
                # L'image a déjà été compressée lors du 'split'
                backup_compress_img_setting = self.config.get('compress_img', False)
                if backup_compress_img_setting:
                    self.config['compress_img'] = False
                fichier = open(splitted_filename, 'rb')
                fichier.seek(0)
                bufimg = fichier.read()
                fichier.close()
                self.save_img(
                    splitted_filename, demande, dem_auto,
                    testbio, bufimg, imgformat = 'JPEG',
                    automate = self.config.get('paillasse', 'AUTOVUE'),
                    id_resultat=id_resultat
                )
                self.config['compress_img'] = backup_compress_img_setting
                # TODO : valider le test
        return
