# -*- coding: utf-8 -*-
u"""
Le worker DMS.

Il s'agit en fait d'un Advia derrière un DMS, le nom du fichier
est différent il faut  integrer le fichier avec son nom complet
"""

# Imports généraux
from __future__ import absolute_import
import datetime
import os
import re

from everything.exceptions import FileOrFilenamException
from everything.workers.advia import WorkerAdvia


class WorkerDms(WorkerAdvia):
    u"""
    Le worker DMS.

    Les différence entre dms et advia c'est
    l'expression régulière pour décoder le nom du fichier , ne pas considérer que c'est un nombre.
    et la prise en compte du code_barre
    Il se compose du no de tube et d'un timestamps en secondes de la forme YYYYMMJJhhmmss
    """

    regexp = '(?P<barcode>[0-9]{12})_(?P<date>[0-9]{14})\.bmp'
    filename_regexp = re.compile(regexp)
    # todo passez en variables nommées

    sql = """select
            da.automate,
            d.id,
            da.id,
            t.id,
            r.id,
            pr.id
        from
            demande d
            join dem_auto da on (d.id = da.demande)
            join dem_auto_test dat on (dat.dem_auto = da.id)
            join resultat r on (r.demande = d.id)
            join testbio t on (t.id = r.testbio and t.id = dat.testbio)
            join resu_auto ra on (ra.id = r.resu_auto and  ra.dem_auto = da.id)
            join prescription as pr on (pr.demande = d.id and pr.testbio = t.id)
        where
            da.automate = %%s and t.code= %%s
            and d.date_demande > now()::date - '%%s days'::interval
            and r.resu = %%s
            and r.date_resu is not null
            and (age(r.date_resu, %%s) > '%%s minutes' and age(r.date_resu, %%s) < '%%s minutes')
            %(extra_where)s
        order by r.date_resu desc"""

    def get_extra_where(self):
        return "and da.tube_auto = %s"

    def check_and_get_sql_params(self, filename):
        u"""
        Vérifie que le fichier est correct.

        Retourne les paramètres à utiliser avec la requête SQL
        """
        fname_regexp = self.config['fname_re']
        if fname_regexp is None:
            fname_regexp = self.filename_regexp
        match = fname_regexp.match(filename)
        if not match:
            raise FileOrFilenamException(
                u"%s - Le nom du fichier ne matche pas l'expression régulière: %s." % (filename, fname_regexp.pattern))
        try:
            filenum = filename
            code_barre = match.group('barcode')
            date_resu = match.group('date')
        except IndexError:
            self.logger.exception(u"%s - Le nom du fichier ne matche pas." % (filename,))
            raise FileOrFilenamException(
                u"%s - Le nom du fichier ne permet pas de trouver le code_barre et la date du résultat." % (filename,))

        self.logger.debug(
            u'%s - Valeur %s attendue (code barre) : %s , date : %s',
            filename, self.config['code_test'], code_barre, date_resu
        )
        datefichier = datetime.datetime.fromtimestamp(
            os.path.getmtime(os.path.join(self.config['dirfich'], filename)))
        self.logger.debug(u"%s - date du fichier : %s date_resu : %s", filename, datefichier, date_resu)
        return [
            self.config['paillasse'],
            self.config['code_test'],
            self.config['age_max_demande'],
            filenum,
            datefichier,
            -self.config['minutes'],
            datefichier,
            self.config['minutes'],
            code_barre,
        ]
