# -*- coding: utf-8 -*-
"""
Worker pour le swing, similaire au worker capi
"""
# Imports généraux
from __future__ import absolute_import
import re
import datetime
import os

from everything.workers.advia import WorkerAdvia
from everything.constants import (
    MCA_VERSION_3,
    MCA_VERSION_4,
)
from everything.exceptions import FileOrFilenamException


class WorkerSwing(WorkerAdvia):
    """
    Worker pour le Swing
    Il a de particulier qu'il peut soit parser le PDF pour trouver
    le code test et le numéro de dossier, soit se baser sur le nom
    du fichier.
    Le resultat n'a pas besion d'etre present, seule la prescription est necessaire.
    """
    filename_regexp = re.compile(
        '(?P<no_dossier>.+)\.pdf')
    imgformat = 'pdf'
    sql = """select
            da.automate,
            d.id,
            da.id,
            t.id,
            r.id,
            pr.id
        from
            demande d
            join dem_auto da on (d.id = da.demande)
            join dem_auto_test dat on (dat.dem_auto = da.id)
            join prescription pr on (pr.demande = d.id and pr.testbio = dat.testbio)
            join testbio t on (t.id = pr.testbio and t.id = dat.testbio)
            left join resultat r
                on (r.demande = d.id and r.testbio = pr.testbio %(extra_where)s)
        where
            da.automate = %%s and t.code= %%s
            and da.%(use_dossier)s = %%s
            and d.date_demande > now()::date - '%%s days'::interval
            and (r.date_resu IS NULL OR (age(r.date_resu, %%s) > '%%s minutes'
                 and age(r.date_resu, %%s) < '%%s minutes'))
            and da.archive=0
        order by d.date_demande desc"""

    def get_extra_where(self):
        if self.config["mca_version"] == MCA_VERSION_3:
            return " and seq = 0 "
        elif self.config["mca_version"] == MCA_VERSION_4:
            return " and actif "

    def check_and_get_sql_params(self, filename):
        fname_regexp = self.config['fname_re']
        if fname_regexp is None:
            fname_regexp = self.filename_regexp
        match = fname_regexp.match(filename)
        if not match:
            raise FileOrFilenamException(
                (u"%s - Le nom du fichier ne matche pas l'expression "
                 u"régulière.") % (filename,))
        code_test = self.config['code_test']
        no_dossier = match.group('no_dossier')
        datefichier = datetime.datetime.fromtimestamp(
            os.path.getmtime(os.path.join(self.config['dirfich'], filename)))
        self.logger.debug(u"dossier:%s, %s - date du fichier : %s", no_dossier, filename, datefichier)
        return [
            self.config['paillasse'],
            self.config.get('transcodage').get(code_test, code_test),
            no_dossier,
            self.config['age_max_demande'],
            datefichier,
            -self.config['minutes'],
            datefichier,
            self.config['minutes'],
        ]

    def save_img(self, *args, **kwargs):
        kwargs['maj_dem_auto_test'] = True
        kwargs['maj_resultat'] = True
        kwargs['maj_prescription'] = True
        return super(WorkerSwing, self).save_img(*args, **kwargs)
