# -*- coding: utf-8 -*-

"""
Le worker Sysmex
"""

from __future__ import absolute_import
from everything.workers.tuple import WorkerTuple
from everything.constants import DONT_MOVE, MOVE_TO_DONE, MOVE_TO_TRASH

class WorkerSysmex(WorkerTuple):
    """
    Classe définissant le worker sysmex

    Il récupère des fichiers via FTP et les insère en BDD
    """
    need_bdd = True
    need_ftp = True
    subfolders = ['traite','erreur']
    def process(self, processed_object):
        oid = processed_object[0]
        # Le driver NG fait déjà ça en amont. Ce n'est pas le cas de CAUTO
        raw_filename = processed_object[1].replace('&R&','/')

        gotfile = self.gotfile(raw_filename, oid = oid)
        if not gotfile:
            return DONT_MOVE
        fichier = open(gotfile, 'rb')
        fichier.seek(0)
        bufimg = fichier.read()
        fichier.close()
        if self.config["type_fichier"]:
            imgformat=self.config["type_fichier"]
        else:
            imgformat="png"
        automate, demande, dem_auto, testbio, prescription = processed_object[2:][:5]
        if self.config["validation_testbio" ]:
            self.logger.info(u"Validation des fichiers intégrés")
            resultat_insertion = self.save_img(
                oid, demande, dem_auto, testbio, bufimg, imgformat=imgformat,
                automate = automate, id_resultat=oid, maj_dem_auto_test = True, maj_resultat = True, maj_prescription = True, id_prescription=prescription)
        else:
            resultat_insertion = self.save_img(
                oid, demande, dem_auto, testbio, bufimg, imgformat=imgformat,
                automate = automate, id_resultat=oid)
        if resultat_insertion in (MOVE_TO_DONE, MOVE_TO_TRASH):
            # l'insertion du graphique en BDD s'est bien passé,
            # mise à jour du statut graphe_ok sur auto.resultat
            cursor = self.conn.cursor()
            try:
                cursor.execute("update resultat set graphe_ok = 1 where id = %s", [oid])
            except:
                self.logger.exception(
                    u"%s - Erreur lors de la mise à jour du statut graphe_ok sur le résultat",
                    oid)
                self.conn.rollback()
            else:
                self.conn.commit()
        return resultat_insertion

    def gotfile(self, raw_filename, oid=None):
        return self.ftpget(raw_filename, oid = oid)

    def list_objects(self):
        """
        Liste les objets à traiter
        """
        cursor = self.conn.cursor()
        cursor.execute("""select
                r.id, r.resu, da.automate, da.demande, da.id, r.testbio, p.id
            from
                resultat as r
                join demande as d on (d.id = r.demande)
                join dem_auto as da on (d.id = da.demande)
                join testbio as t on (t.id = r.testbio)
                join dem_auto_test as dat on (dat.dem_auto = da.id and dat.testbio = t.id)
                join type_resu as tr on (tr.typ = t.type_resu)
                join prescription as p on (p.demande = d.id and p.testbio = r.testbio)
            where
                da.automate = %s
                and tr.code = 'FIC'
                and coalesce(r.resu, '') != ''
                and d.date_demande > now()::date - '%s days'::interval
                and r.graphe_ok is NULL
            order by r.id desc""",
            [self.config['paillasse'], self.config['age_max_demande']])
        resus = cursor.fetchall()
        self.conn.commit()

        return resus

class WorkerSysmexSFTP(WorkerSysmex):
    need_sftp = True
    need_ftp = False

    def gotfile(self, raw_filename, oid=None):
        try :
            return self.sftpget(raw_filename)
        except IOError:
            self.logger.exception('Fichier distant introuvable %s' % raw_filename)
            return None
